@@ -228,9 +228,9 @@ class SnsToLambdaProps:
         :summary: The properties for the SnsToLambda class.
         '''
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(topic_props, dict):
-            topic_props = TopicProps(**topic_props)
+            topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
         if __debug__:
             type_hints = typing.get_type_hints(SnsToLambdaProps.__init__)
             check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
